# = Class: environment
#
# The class to:
#   - install apache2-utils, curl, git, lynx-cur, mc, tree, expect, httpie
#   - add cd /vagrant to vagrant's profile
#   - remove mesg n from root's profile
#
# === Parameters
#
# None
#

class environment (
    $modifyProfileFiles = undef
) {

    # validate_platform() function comes from
    # puppet module gajdaw/diverse_functions
    #
    #     https://forge.puppetlabs.com/gajdaw/diverse_functions
    #
    if !validate_platform($module_name) {
        fail("Platform not supported in module '${module_name}'.")
    }

    #
    # Handle parameters
    #
    include environment::params

    $param_modifyProfileFiles = $modifyProfileFiles ? {
        undef   => $::environment::params::modifyProfileFiles,
        default => $modifyProfileFiles
    }

    include stdlib

    $deps = [
        'apache2-utils',
        'curl',
        'git',
        'lynx-cur',
        'mc',
        'tree',
        'expect',
        'httpie',
        'parallel'
    ]
    ensure_packages($deps)

    if $param_modifyProfileFiles {

        file_line { 'environment::cd-vagrant':
            ensure => present,
            path   => '/home/vagrant/.profile',
            line   => 'cd /vagrant',
            match  => 'cd /vagrant',
        }

        file_line { 'environment::remove-mesg-n':
            ensure => absent,
            path   => '/root/.profile',
            line   => 'mesg n',
        }

    }

}
